package com.goldencode.testcases.dmo.p2j_test.impl;

import java.io.Serializable;
import java.util.*;
import com.goldencode.p2j.persist.*;
import com.goldencode.p2j.util.*;
import com.goldencode.testcases.dmo.p2j_test.*;

/**
 * Data Model Object corresponding with table <code>p2j_test.person</code>
 * (previously <code>p2j_test.person</code>).
 * <p>
 * Test table with variety of indexes
 */
@LegacyTable(name = "person")
@LegacyIndexes(
{
   @LegacyIndex(name = "site-emp", converted = "person_site_emp"),
   @LegacyIndex(name = "comments", converted = "person_comments"),
   @LegacyIndex(name = "emp-ssn", converted = "person_emp_ssn"),
   @LegacyIndex(name = "exten", converted = "person_exten"),
   @LegacyIndex(name = "hire-date", converted = "person_hire_date"),
   @LegacyIndex(name = "name", converted = "person_name"),
   @LegacyIndex(name = "pay-type", converted = "person_pay_type"),
   @LegacyIndex(name = "phone", converted = "person_phone"),
   @LegacyIndex(name = "term-date", converted = "person_term_date")
})
public class PersonImpl
implements Serializable,
           Persistable,
           Person
{
   /** Surrogate primary key */
   private Long id = null;

   /** Site ID */
   @LegacyField(name = "site-id")
   private final integer siteId;

   /** Data member */
   @LegacyField(name = "emp-num")
   private final integer empNum;

   /** First */
   @LegacyField(name = "first-name")
   private final character firstName;

   /** Last */
   @LegacyField(name = "last-name")
   private final character lastName;

   /** MI */
   @LegacyField(name = "middle-init")
   private final character middleInit;

   /** SSN */
   @LegacyField(name = "ssn")
   private final character ssn;

   /** Pay Type */
   @LegacyField(name = "pay-type")
   private final character payType;

   /** Hired */
   @LegacyField(name = "hire-date")
   private final date hireDate;

   /** Terminated */
   @LegacyField(name = "term-date")
   private final date termDate;

   /** Data member */
   @LegacyField(name = "comments")
   private final character comments;

   /** Area Code */
   @LegacyField(name = "area-code")
   private final character areaCode;

   /** Phone */
   @LegacyField(name = "phone-number")
   private final character phoneNumber;

   /** Ext */
   @LegacyField(name = "extension")
   private final character extension1;

   /** Ext */
   @LegacyField(name = "extension")
   private final character extension2;

   /** Ext */
   @LegacyField(name = "extension")
   private final character extension3;

   /** Ext */
   @LegacyField(name = "extension")
   private final character extension4;

   /** Ext */
   @LegacyField(name = "extension")
   private final character extension5;

   /** Ext */
   @LegacyField(name = "extension")
   private final character extension6;

   /** Data member */
   @LegacyField(name = "schedule")
   private final character scheduleFirst;

   /** Data member */
   @LegacyField(name = "schedule")
   private final character scheduleSecond;

   /** Data member */
   @LegacyField(name = "schedule")
   private final character scheduleThird;

   /** Hours */
   @LegacyField(name = "hours")
   private final integer hours1;

   /** Hours */
   @LegacyField(name = "hours")
   private final integer hours2;

   /** Hours */
   @LegacyField(name = "hours")
   private final integer hours3;

   /** Hours */
   @LegacyField(name = "hours")
   private final integer hours4;

   /** Hours */
   @LegacyField(name = "hours")
   private final integer hours5;

   /**
    * List of composite properties; 3 elements of type {@link
    * PersonImpl.Composite3 Composite3}
    */
   private List composite3 = new ArrayList(3);

   /**
    * Default constructor.
    */
   public PersonImpl()
   {
      siteId = new integer(0);
      empNum = new integer(0);
      firstName = new character("");
      lastName = new character("");
      middleInit = new character("");
      ssn = new character();
      payType = new character("");
      hireDate = new date();
      termDate = new date();
      comments = new character("");
      areaCode = new character("");
      phoneNumber = new character("");
      extension1 = new character("");
      extension2 = new character("");
      extension3 = new character("");
      extension4 = new character("");
      extension5 = new character("");
      extension6 = new character("");
      scheduleFirst = new character("");
      scheduleSecond = new character("");
      scheduleThird = new character("");
      hours1 = new integer(0);
      hours2 = new integer(0);
      hours3 = new integer(0);
      hours4 = new integer(0);
      hours5 = new integer(0);
      
      // Populate Composite3 list.
      for (int i = 0; i < 3; i++)
      {
         composite3.add(new Composite3());
      }
   }

   /**
    * Make a deep copy of the current DMO instance and return it.
    * 
    * @return  A new instance of this class whose data is identical to that of
    *          this instance.
    */
   public Undoable deepCopy()
   {
      Undoable copy = new PersonImpl();
      copy.assign(this);
      return copy;
   }

   /**
    * Modify the contained data of the instance to copy the instance data from
    * the given, backup instance.
    * 
    * @param   old
    *          The backup instance from which to copy data.
    */
   public void assign(Undoable old)
   {
      PersonImpl from = (PersonImpl) old;
      setId(from.getId());
      setSiteId(from.getSiteId());
      setEmpNum(from.getEmpNum());
      setFirstName(from.getFirstName());
      setLastName(from.getLastName());
      setMiddleInit(from.getMiddleInit());
      setSsn(from.getSsn());
      setPayType(from.getPayType());
      setHireDate(from.getHireDate());
      setTermDate(from.getTermDate());
      setComments(from.getComments());
      setAreaCode(from.getAreaCode());
      setPhoneNumber(from.getPhoneNumber());
      setExtension1(from.getExtension1());
      setExtension2(from.getExtension2());
      setExtension3(from.getExtension3());
      setExtension4(from.getExtension4());
      setExtension5(from.getExtension5());
      setExtension6(from.getExtension6());
      setScheduleFirst(from.getScheduleFirst());
      setScheduleSecond(from.getScheduleSecond());
      setScheduleThird(from.getScheduleThird());
      setHours1(from.getHours1());
      setHours2(from.getHours2());
      setHours3(from.getHours3());
      setHours4(from.getHours4());
      setHours5(from.getHours5());
      
      // Assign Composite3 properties.
      for (int i = 0; i < 3; i++)
      {
         setEmail(i, from.getEmail(i));
      }
   }

   /**
    * Getter: Surrogate primary key
    * 
    * @return  Primary key
    */
   public Long getId()
   {
      return id;
   }

   /**
    * Setter: Surrogate primary key
    * 
    * @param   id
    *          Primary key
    */
   public void setId(Long id)
   {
      this.id = id;
   }

   /**
    * Getter: Site ID
    * 
    * @return  Site ID
    */
   public integer getSiteId()
   {
      return (new integer(siteId));
   }

   /**
    * Setter: Site ID
    * 
    * @param   siteId
    *          Site ID
    */
   public void setSiteId(NumberType siteId)
   {
      this.siteId.assign(siteId, true);
   }

   /**
    * Getter: empNum
    * 
    * @return  empNum
    */
   public integer getEmpNum()
   {
      return (new integer(empNum));
   }

   /**
    * Setter: empNum
    * 
    * @param   empNum
    *          empNum
    */
   public void setEmpNum(NumberType empNum)
   {
      this.empNum.assign(empNum, true);
   }

   /**
    * Getter: First
    * 
    * @return  First
    */
   public character getFirstName()
   {
      return (new character(firstName));
   }

   /**
    * Setter: First
    * 
    * @param   firstName
    *          First
    */
   public void setFirstName(Text firstName)
   {
      this.firstName.assign(firstName, true);
   }

   /**
    * Getter: Last
    * 
    * @return  Last
    */
   public character getLastName()
   {
      return (new character(lastName));
   }

   /**
    * Setter: Last
    * 
    * @param   lastName
    *          Last
    */
   public void setLastName(Text lastName)
   {
      this.lastName.assign(lastName, true);
   }

   /**
    * Getter: MI
    * 
    * @return  MI
    */
   public character getMiddleInit()
   {
      return (new character(middleInit));
   }

   /**
    * Setter: MI
    * 
    * @param   middleInit
    *          MI
    */
   public void setMiddleInit(Text middleInit)
   {
      this.middleInit.assign(middleInit, true);
   }

   /**
    * Getter: SSN
    * 
    * @return  SSN
    */
   public character getSsn()
   {
      return (new character(ssn));
   }

   /**
    * Setter: SSN
    * 
    * @param   ssn
    *          SSN
    */
   public void setSsn(Text ssn)
   {
      this.ssn.assign(ssn, true);
   }

   /**
    * Getter: Pay Type
    * 
    * @return  Pay Type
    */
   public character getPayType()
   {
      return (new character(payType));
   }

   /**
    * Setter: Pay Type
    * 
    * @param   payType
    *          Pay Type
    */
   public void setPayType(Text payType)
   {
      this.payType.assign(payType, true);
   }

   /**
    * Getter: Hired
    * 
    * @return  Hired
    */
   public date getHireDate()
   {
      return (new date(hireDate));
   }

   /**
    * Setter: Hired
    * 
    * @param   hireDate
    *          Hired
    */
   public void setHireDate(date hireDate)
   {
      this.hireDate.assign(hireDate, true);
   }

   /**
    * Getter: Terminated
    * 
    * @return  Terminated
    */
   public date getTermDate()
   {
      return (new date(termDate));
   }

   /**
    * Setter: Terminated
    * 
    * @param   termDate
    *          Terminated
    */
   public void setTermDate(date termDate)
   {
      this.termDate.assign(termDate, true);
   }

   /**
    * Getter: comments
    * 
    * @return  comments
    */
   public character getComments()
   {
      return (new character(comments));
   }

   /**
    * Setter: comments
    * 
    * @param   comments
    *          comments
    */
   public void setComments(Text comments)
   {
      this.comments.assign(comments, true);
   }

   /**
    * Getter: Area Code
    * 
    * @return  Area Code
    */
   public character getAreaCode()
   {
      return (new character(areaCode));
   }

   /**
    * Setter: Area Code
    * 
    * @param   areaCode
    *          Area Code
    */
   public void setAreaCode(Text areaCode)
   {
      this.areaCode.assign(areaCode, true);
   }

   /**
    * Getter: Phone
    * 
    * @return  Phone
    */
   public character getPhoneNumber()
   {
      return (new character(phoneNumber));
   }

   /**
    * Setter: Phone
    * 
    * @param   phoneNumber
    *          Phone
    */
   public void setPhoneNumber(Text phoneNumber)
   {
      this.phoneNumber.assign(phoneNumber, true);
   }

   /**
    * Getter: Ext
    * 
    * @return  Ext
    */
   public character getExtension1()
   {
      return (new character(extension1));
   }

   /**
    * Setter: Ext
    * 
    * @param   extension1
    *          Ext
    */
   public void setExtension1(Text extension1)
   {
      this.extension1.assign(extension1, true);
   }

   /**
    * Getter: Ext
    * 
    * @return  Ext
    */
   public character getExtension2()
   {
      return (new character(extension2));
   }

   /**
    * Setter: Ext
    * 
    * @param   extension2
    *          Ext
    */
   public void setExtension2(Text extension2)
   {
      this.extension2.assign(extension2, true);
   }

   /**
    * Getter: Ext
    * 
    * @return  Ext
    */
   public character getExtension3()
   {
      return (new character(extension3));
   }

   /**
    * Setter: Ext
    * 
    * @param   extension3
    *          Ext
    */
   public void setExtension3(Text extension3)
   {
      this.extension3.assign(extension3, true);
   }

   /**
    * Getter: Ext
    * 
    * @return  Ext
    */
   public character getExtension4()
   {
      return (new character(extension4));
   }

   /**
    * Setter: Ext
    * 
    * @param   extension4
    *          Ext
    */
   public void setExtension4(Text extension4)
   {
      this.extension4.assign(extension4, true);
   }

   /**
    * Getter: Ext
    * 
    * @return  Ext
    */
   public character getExtension5()
   {
      return (new character(extension5));
   }

   /**
    * Setter: Ext
    * 
    * @param   extension5
    *          Ext
    */
   public void setExtension5(Text extension5)
   {
      this.extension5.assign(extension5, true);
   }

   /**
    * Getter: Ext
    * 
    * @return  Ext
    */
   public character getExtension6()
   {
      return (new character(extension6));
   }

   /**
    * Setter: Ext
    * 
    * @param   extension6
    *          Ext
    */
   public void setExtension6(Text extension6)
   {
      this.extension6.assign(extension6, true);
   }

   /**
    * Indexed Getter: email
    * 
    * @param   index
    *          Index of element (where <code>0 &lt;= <em>index</em> &lt;
    *          3</code>).
    * 
    * @return  email
    */
   public character getEmail(int index)
   {
      return ((Composite3) composite3.get(index)).getEmail();
   }

   /**
    * Getter: email
    * 
    * @return  email
    */
   public character[] getEmail()
   {
      character[] _email = new character[3];
      for (int i = 0; i < 3; i++)
      {
         _email[i] = getEmail(i);
      }
      return _email;
   }

   /**
    * Indexed Getter: email
    * 
    * @param   index
    *          Index of element (where <code>0 &lt;= <em>index</em> &lt;
    *          3</code>).
    * 
    * @return  email
    */
   public character getEmail(NumberType index)
   {
      return getEmail(index.intValue());
   }

   /**
    * Indexed Setter: email
    * 
    * @param   index
    *          Index of element (where <code>0 &lt;= <em>index</em> &lt;
    *          3</code>).
    * @param   element
    *          email
    */
   public void setEmail(int index, Text element)
   {
      ((Composite3) composite3.get(index)).setEmail(element);
   }

   /**
    * Indexed Setter: email
    * 
    * @param   index
    *          Index of element (where <code>0 &lt;= <em>index</em> &lt;
    *          3</code>).
    * @param   element
    *          email
    */
   public void setEmail(NumberType index, Text element)
   {
      setEmail(index.intValue(), element);
   }

   /**
    * Set all elements of the target list property to the given scalar value.
    * Modifies the contents of: email
    * 
    * @param   element
    *          Scalar value to which to set all elements of: email
    */
   public void setEmail(Text element)
   {
      int len = composite3.size();
      for (int i = 0; i < len; i++)
      {
         setEmail(i, element);
      }
   }

   /**
    * Set as many elements of the target list property as are provided in the
    * given array of scalar values. Modifies the contents of: email
    * <p>
    * If the given array is larger than the target list, any additional
    * elements in the given array are ignored. If the target array is smaller
    * than the target list, only those elements whose array indices match are
    * updated.
    * 
    * @param   elements
    *          Array of scalar values to which to set the corresponding
    *          elements of: email
    */
   public void setEmail(Text[] elements)
   {
      int len = Math.min(elements.length, composite3.size());
      for (int i = 0; i < len; i++)
      {
         setEmail(i, elements[i]);
      }
   }

   /**
    * Report number of list elements for email
    * 
    * @return  Number of list elements for email
    */
   public integer sizeEmail()
   {
      return (new integer(composite3.size()));
   }

   /**
    * Getter: scheduleFirst
    * 
    * @return  scheduleFirst
    */
   public character getScheduleFirst()
   {
      return (new character(scheduleFirst));
   }

   /**
    * Setter: scheduleFirst
    * 
    * @param   scheduleFirst
    *          scheduleFirst
    */
   public void setScheduleFirst(Text scheduleFirst)
   {
      this.scheduleFirst.assign(scheduleFirst, true);
   }

   /**
    * Getter: scheduleSecond
    * 
    * @return  scheduleSecond
    */
   public character getScheduleSecond()
   {
      return (new character(scheduleSecond));
   }

   /**
    * Setter: scheduleSecond
    * 
    * @param   scheduleSecond
    *          scheduleSecond
    */
   public void setScheduleSecond(Text scheduleSecond)
   {
      this.scheduleSecond.assign(scheduleSecond, true);
   }

   /**
    * Getter: scheduleThird
    * 
    * @return  scheduleThird
    */
   public character getScheduleThird()
   {
      return (new character(scheduleThird));
   }

   /**
    * Setter: scheduleThird
    * 
    * @param   scheduleThird
    *          scheduleThird
    */
   public void setScheduleThird(Text scheduleThird)
   {
      this.scheduleThird.assign(scheduleThird, true);
   }

   /**
    * Getter: Hours
    * 
    * @return  Hours
    */
   public integer getHours1()
   {
      return (new integer(hours1));
   }

   /**
    * Setter: Hours
    * 
    * @param   hours1
    *          Hours
    */
   public void setHours1(NumberType hours1)
   {
      this.hours1.assign(hours1, true);
   }

   /**
    * Getter: Hours
    * 
    * @return  Hours
    */
   public integer getHours2()
   {
      return (new integer(hours2));
   }

   /**
    * Setter: Hours
    * 
    * @param   hours2
    *          Hours
    */
   public void setHours2(NumberType hours2)
   {
      this.hours2.assign(hours2, true);
   }

   /**
    * Getter: Hours
    * 
    * @return  Hours
    */
   public integer getHours3()
   {
      return (new integer(hours3));
   }

   /**
    * Setter: Hours
    * 
    * @param   hours3
    *          Hours
    */
   public void setHours3(NumberType hours3)
   {
      this.hours3.assign(hours3, true);
   }

   /**
    * Getter: Hours
    * 
    * @return  Hours
    */
   public integer getHours4()
   {
      return (new integer(hours4));
   }

   /**
    * Setter: Hours
    * 
    * @param   hours4
    *          Hours
    */
   public void setHours4(NumberType hours4)
   {
      this.hours4.assign(hours4, true);
   }

   /**
    * Getter: Hours
    * 
    * @return  Hours
    */
   public integer getHours5()
   {
      return (new integer(hours5));
   }

   /**
    * Setter: Hours
    * 
    * @param   hours5
    *          Hours
    */
   public void setHours5(NumberType hours5)
   {
      this.hours5.assign(hours5, true);
   }

   /**
    * Inner class which composites properties of like extent. All properties
    * migrated from the legacy table <code>p2j_test.person</code> of extent 3
    * are data members of this class.
    */
   static class Composite3
   implements Serializable
   {
      /** Data member */
      @LegacyField(name = "email")
      private final character email;

      /**
       * Default constructor.
       */
      public Composite3()
      {
         email = new character("");
      }

      /**
       * Getter: email
       * 
       * @return  email
       */
      public character getEmail()
      {
         return (new character(email));
      }

      /**
       * Setter: email
       * 
       * @param   email
       *          email
       */
      public void setEmail(Text email)
      {
         this.email.assign(email, true);
      }
   }
}
